==> zio-aws-personalize_3-5.17.104.5-sources.jar: zio/aws/personalize/model/CreateRecommenderResponse.scala <==
package zio.aws.personalize.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.personalize.model.primitives.Arn
import scala.jdk.CollectionConverters.*
final case class CreateRecommenderResponse(recommenderArn: Option[Arn] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse = {
    import CreateRecommenderResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
      .builder()
      .optionallyWith(
        recommenderArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.recommenderArn)
      .build()
  }
  def asReadOnly: zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly =
    zio.aws.personalize.model.CreateRecommenderResponse.wrap(buildAwsValue())
}
object CreateRecommenderResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalize.model.CreateRecommenderResponse =
      zio.aws.personalize.model
        .CreateRecommenderResponse(recommenderArn.map(value => value))
    def recommenderArn: Option[Arn]
    def getRecommenderArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("recommenderArn", recommenderArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ) extends zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly {
    override val recommenderArn: Option[Arn] = scala
      .Option(impl.recommenderArn())
      .map(value => zio.aws.personalize.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ): zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-personalize_3-5.17.217.1-sources.jar: zio/aws/personalize/model/CreateRecommenderResponse.scala <==
package zio.aws.personalize.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.personalize.model.primitives.Arn
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateRecommenderResponse(
    recommenderArn: Optional[Arn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse = {
    import CreateRecommenderResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
      .builder()
      .optionallyWith(
        recommenderArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.recommenderArn)
      .build()
  }
  def asReadOnly: zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly =
    zio.aws.personalize.model.CreateRecommenderResponse.wrap(buildAwsValue())
}
object CreateRecommenderResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalize.model.CreateRecommenderResponse =
      zio.aws.personalize.model
        .CreateRecommenderResponse(recommenderArn.map(value => value))
    def recommenderArn: Optional[Arn]
    def getRecommenderArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("recommenderArn", recommenderArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ) extends zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly {
    override val recommenderArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.recommenderArn())
      .map(value => zio.aws.personalize.model.primitives.Arn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalize.model.CreateRecommenderResponse
  ): zio.aws.personalize.model.CreateRecommenderResponse.ReadOnly = new Wrapper(
    impl
  )
}
